#
# spec file for package python-rst.linker
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   rst.linker
%{?sle15_python_module_pythons}
Name:           python-rst.linker
Version:        2.4.0
Release:        2.1
Summary:        Changelog link and timestamp adding Sphinx plugin
License:        MIT
URL:            https://github.com/jaraco/rst.linker
Source:         https://files.pythonhosted.org/packages/source/r/%{_name}/%{_name}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module path}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
%if 0%{python_version_nodots} < 38
BuildRequires:  %{python_module importlib-metadata if %python-version < 3.8}
Requires:       python-importlib-metadata
%endif
Requires:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
rst.linker is a Sphinx plugin to add links and timestamps to the
changelog.

%prep
%setup -q -n %{_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
# This needs a fix if there will be any more rst.* namespace packages (none on PyPI so far)
%{python_sitelib}/rst
%{python_sitelib}/rst.linker-%{version}*-info

%changelog
* Tue Sep 19 2023 Dirk Müller <dmueller@suse.com>
- remove buildrequires that are not used on sle15
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.0:
  * Supply the encoding, fixing EncodingWarnings.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Aug 29 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.3.1
  * Packaging refresh.
  + #12: Added locale stability for tests.
- v2.3.0:
  * #9: Fixed syntax errors in docs.
  * Require Python 3.7 or later.
- v2.2.0
  * #8: Prefer author date to committer date when adding SCM
    timestamps, reverting change in 2.1, and this time tracking the
    motivation more carefully.
- v2.1.1: Fix Github Actions badge.
- v2.1.0 Prefer committer date to author date when adding SCM
  timestamps.
- Don't build the docs
* Sat Sep 26 2020 Hans-Peter Jansen <hpj@urpla.net>
- Replace python-patrh.py with python-path
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 2.0.0
  * Drop support for Python 3.5 and earlier.
* Tue Mar 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix building on Leap
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.11:
  * Now supply the version of the package during Sphinx setup.
  * Also supply "parallel_read_safe=True"
* Fri Jun  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
- Run py3 only sphinx build as new sphinx does not provide py2
  variant anymore
* Wed Feb 27 2019 John Vandenberg <jayvdb@gmail.com>
- Add LICENSE
- Run Sphinx on Python 2 also
- Update to v1.10
  * Refreshed package metadata.
  * Package now presents the ``rst`` package a pkg-util
    namespace package (instead of pkg_resources).
* Sun Jul  9 2017 aloisio@gmx.com
- Fixed dateutil requires
* Tue Jul  4 2017 aloisio@gmx.com
- Update to version 1.9
  * Replacer now adds the Sphinx config namespace to the
    replacements, meaning that names like ``project``
    or ``copyright`` may be referenced in the format
    strings. This feature is particularly useful when
    coupled with the `jaraco.packaging
    <https://pypi.org/project/jaraco.packaging>`.sphinx
    plugin, which supplies a ``package_url``.
  1.8.2:
  * Added project description and updated changelog.
  1.8.1:
  * Issue #4: Prefer public API of ``app.confdir`` to private
    API.
  1.8:
  * Issue #4: Resolve deterministically the filenames relative to
    the config file.
  * *semver deviation*: This change is backward-incompatible
    for projects that relied on paths relative to the cwd where
    the cwd was not the directory of the config file.
- Converted to single-spec
* Sat Jul 30 2016 sor.alexei@meowr.ru
- Initial package.
